Function rusty_doors::door_call_slice
source · pub fn door_call_slice<T, U: Default>(fd: c_int, x: &[T]) -> UExpand description
Call the door referenced by fd with argument slice x. Returns doo call
result by value.
pub fn door_call_slice<T, U: Default>(fd: c_int, x: &[T]) -> UCall the door referenced by fd with argument slice x. Returns doo call
result by value.