Function rusty_doors::door_callp

source ·
pub fn door_callp<T, U>(fd: c_int, x: T, res: NonNull<*mut U>) -> *mut U
Call the door referenced by fd with argument data x. The address pointed to by res will be allocated by the door, and the result placed at that location. The return value is the address to the pointed to address.