Function rusty_doors::door_run
source · pub fn door_run(fd: i32, path: &CStr) -> !Expand description
Run a door server for the door handler referenced by fd. fd should be
the result of calling door_create.
pub fn door_run(fd: i32, path: &CStr) -> !Run a door server for the door handler referenced by fd. fd should be
the result of calling door_create.